@@ -12,7 +12,8 @@ from lib2to3.pytree import Leaf, Node
 from lib2to3.pygram import token
 
 from future.tests.base import (CodeHandler, unittest, skip26, reformat_code,
-                               order_future_lines)
+                               order_future_lines, expectedFailurePY26)
+from future.utils import PY2
 
 
 class TestLibFuturize(unittest.TestCase):
@@ -308,6 +309,7 @@ class TestFuturizeSimple(CodeHandler):
         """
         self.unchanged(code)
 
+    @expectedFailurePY26
     def test_import_builtins(self):
         before = """
         a = raw_input()
@@ -358,7 +360,7 @@ class TestFuturizeSimple(CodeHandler):
         """
         self.convert_check(before, after, ignore_imports=False)
     
-    @skip26
+    @expectedFailurePY26
     def test_source_coding_utf8(self):
         """
         Tests to ensure that the source coding line is not corrupted or
@@ -450,6 +452,7 @@ class TestFuturizeSimple(CodeHandler):
         # with open('/tmp/' + filename, 'w') as tarball:
         #     tarball.write(r2.content)
 
+    @expectedFailurePY26
     def test_raw_input(self):
         """
         Passes in a string to the waiting input() after futurize
@@ -682,7 +685,7 @@ class TestFuturizeStage1(CodeHandler):
         for i in xrange(10):
             pass
         '''
-        self.unchanged(code, stages=[1])
+        self.unchanged(code, stages=[1], run=PY2)
 
     @unittest.expectedFailure
     def test_absolute_import_changes(self):
@@ -719,7 +722,7 @@ class TestFuturizeStage1(CodeHandler):
         HTMLParser.HTMLParser
         assert list(ifilterfalse(lambda x: x % 2, [2, 4])) == [2, 4]
         """
-        self.unchanged(before, stages=[1])
+        self.unchanged(before, stages=[1], run=PY2)
 
     def test_print(self):
         before = """
@@ -837,8 +840,8 @@ class TestFuturizeStage1(CodeHandler):
         except AttributeError as e:
             pass
         """
-        self.convert_check(before, after, stages=[1])
-        
+        self.convert_check(before, after, stages=[1], run=PY2)
+
     def test_octal_literals(self):
         before = """
         mode = 0644
