@@ -18,7 +18,7 @@ from subprocess import CalledProcessError
 class TestStandardLibraryRenames(CodeHandler):
 
     def setUp(self):
-        self.interpreter = 'python'
+        self.interpreter = sys.executable
         standard_library.install_hooks()
         super(TestStandardLibraryRenames, self).setUp()
 
@@ -51,8 +51,12 @@ class TestStandardLibraryRenames(CodeHandler):
         self.assertTrue(not any([standard_library.is_py2_stdlib_module(module)
                              for module in externalmodules]))
 
-        py2modules = [sys, tempfile, os, copy, textwrap]
+        py2modules = [sys, tempfile, copy, textwrap]
         if utils.PY2:
+            # Debugging:
+            for module in py2modules:
+                if hasattr(module, '__file__'):
+                    print(module.__file__, file=sys.stderr)
             self.assertTrue(all([standard_library.is_py2_stdlib_module(module)
                                  for module in py2modules]))
         else:
@@ -240,6 +244,7 @@ class TestStandardLibraryRenames(CodeHandler):
         self.assertEqual(list(zip_longest(a, b)),
                          [(1, 2), (2, 4), (None, 6)])
 
+    @unittest.skipIf(utils.PY3, 'generic import tests are for Py2 only')
     def test_import_failure_from_module(self):
         """
         Tests whether e.g. "import socketserver" succeeds in a module
